Program

Struct Program 

pub struct Program<'info, T = ()> { /* private fields */ }
Type validating that the account is the given Program

The type has a programdata_address function that will return Option::Some if the program is owned by the BPFUpgradeableLoader which will contain the programdata_address property of the Program variant of the UpgradeableLoaderState enum.

Table of Contents

Basic Functionality

For Program<'info, T> where T implements Id: Checks:

  • account_info.key == expected_program
  • account_info.executable == true

Generic Program Validation

For Program<'info> (without type parameter):

  • Only checks: account_info.executable == true
  • Use this when you only need to verify that an address is executable, without validating against a specific program ID.

Example

#[program]
mod my_program {
    fn set_admin_settings(...){...}
}

#[account]
#[derive(Default)]
pub struct AdminSettings {
    ...
}

#[derive(Accounts)]
pub struct SetAdminSettings<'info> {
    #[account(mut, seeds = [b"admin"], bump)]
    pub admin_settings: Account<'info, AdminSettings>,
    #[account(constraint = program.programdata_address()? == Some(program_data.key()))]
    pub program: Program<'info, MyProgram>,
    #[account(constraint = program_data.upgrade_authority_address == Some(authority.key()))]
    pub program_data: Account<'info, ProgramData>,
    pub authority: Signer<'info>,
}

The given program has a function with which the upgrade authority can set admin settings.

The required constraints are as follows:

  • program is the account of the program itself. Its constraint checks that program_data is the account that contains the program’s upgrade authority. Implicitly, this checks that program is a BPFUpgradeable program (program.programdata_address()? will be None if it’s not).
  • program_data’s constraint checks that its upgrade authority is the authority account.
  • Finally, authority needs to sign the transaction.

Generic Program Example

#[derive(Accounts)]
pub struct ValidateExecutableProgram<'info> {
    // Only validates that the provided account is executable
    pub any_program: Program<'info>,
    pub authority: Signer<'info>,
}

Out of the Box Types

Between the anchor_lang and anchor_spl crates, the following Program types are provided out of the box:

Implementations

Source

impl<'a, T> Program<'a, T>

Methods from Deref<Target = AccountInfo<'info>>

pub fn signer_key(&self) -> Option<&Address>

pub fn unsigned_key(&self) -> &Address

pub fn lamports(&self) -> u64

pub fn try_lamports(&self) -> Result<u64, ProgramError>

pub unsafe fn original_data_len(&self) -> usize

Return the account’s original data length when it was serialized for the current program invocation.

Safety

This method assumes that the original data length was serialized as a u32 integer in the 4 bytes immediately preceding the serialized account key.

pub fn data_len(&self) -> usize

pub fn try_data_len(&self) -> Result<usize, ProgramError>

pub fn data_is_empty(&self) -> bool

pub fn try_data_is_empty(&self) -> Result<bool, ProgramError>

pub fn try_borrow_lamports(&self) -> Result<Ref<'_, &mut u64>, ProgramError>

pub fn try_borrow_mut_lamports( &self, ) -> Result<RefMut<'_, &'a mut u64>, ProgramError>

pub fn try_borrow_data(&self) -> Result<Ref<'_, &mut [u8]>, ProgramError>

pub fn try_borrow_mut_data( &self, ) -> Result<RefMut<'_, &'a mut [u8]>, ProgramError>

pub fn resize(&self, new_len: usize) -> Result<(), ProgramError>

Resize the account’s data: Either truncating or zero extending.

Note: Account data can be increased within a single call by up to solana_program::entrypoint::MAX_PERMITTED_DATA_INCREASE bytes.

Safety

This method makes assumptions about the layout and location of memory referenced by AccountInfo fields. It should only be called for instances of AccountInfo that were created by the runtime and received in the process_instruction entrypoint of a program.

pub fn assign(&self, new_owner: &Address)