pub struct UncheckedAccount<'info>(/* private fields */);Expand description
Explicit wrapper for AccountInfo types to emphasize that no checks are performed
Implementations
Sourceimpl<'info> UncheckedAccount<'info>
impl<'info> UncheckedAccount<'info>
pub fn try_from(acc_info: &'info AccountInfo<'info>) -> Self
Methods from Deref<Target = AccountInfo<'info>>
pub fn signer_key(&self) -> Option<&Address>
pub fn unsigned_key(&self) -> &Address
pub fn lamports(&self) -> u64
pub fn try_lamports(&self) -> Result<u64, ProgramError>
Sourcepub unsafe fn original_data_len(&self) -> usize
pub unsafe fn original_data_len(&self) -> usize
Return the account’s original data length when it was serialized for the current program invocation.
Safety
This method assumes that the original data length was serialized as a u32 integer in the 4 bytes immediately preceding the serialized account key.
pub fn data_len(&self) -> usize
pub fn try_data_len(&self) -> Result<usize, ProgramError>
pub fn data_is_empty(&self) -> bool
pub fn try_data_is_empty(&self) -> Result<bool, ProgramError>
pub fn try_borrow_lamports(&self) -> Result<Ref<'_, &mut u64>, ProgramError>
pub fn try_borrow_mut_lamports( &self, ) -> Result<RefMut<'_, &'a mut u64>, ProgramError>
pub fn try_borrow_data(&self) -> Result<Ref<'_, &mut [u8]>, ProgramError>
pub fn try_borrow_mut_data( &self, ) -> Result<RefMut<'_, &'a mut [u8]>, ProgramError>
Sourcepub fn resize(&self, new_len: usize) -> Result<(), ProgramError>
pub fn resize(&self, new_len: usize) -> Result<(), ProgramError>
Resize the account’s data: Either truncating or zero extending.
Note: Account data can be increased within a single call by up to
solana_program::entrypoint::MAX_PERMITTED_DATA_INCREASE bytes.
Safety
This method makes assumptions about the layout and location of memory
referenced by AccountInfo fields. It should only be called for
instances of AccountInfo that were created by the runtime and received
in the process_instruction entrypoint of a program.
pub fn assign(&self, new_owner: &Address)