pub struct CreateAccountBumps {}Trait Implementations
Sourceimpl<'info> Accounts<'info, CreateAccountBumps> for CreateAccount<'info>where
'info: 'info,
impl<'info> Accounts<'info, CreateAccountBumps> for CreateAccount<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut CreateAccountBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut CreateAccountBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl Clone for CreateAccountBumps
impl Clone for CreateAccountBumps
Sourcefn clone(&self) -> CreateAccountBumps
fn clone(&self) -> CreateAccountBumps
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CreateAccountBumps
Sourceimpl Debug for CreateAccountBumps
impl Debug for CreateAccountBumps