pub trait DuplicateMutableAccountKeys {
// Required method
fn duplicate_mutable_account_keys(&self) -> Vec<Pubkey>;
}Expand description
Returns the pubkeys of mutable accounts that serialize on exit. Used by the duplicate mutable account validation to check across composite (nested) account struct boundaries.